@@ -216,6 +216,27 @@ class Client:
 
         experiment = Experiment.parse_obj(self.wait_for_response("experiment", exp_id))
 
+        #### replace model_id in experiment.attributes ###
+        # In fact, both res["experiment"]["model_id"] and
+        # res['experiment']['attributes'][{algo name}]['model_id'] are corex_model_id,
+        # so need to convert to web_model_id.
+        # But res['best_model_id'] is web_model_id.
+        model_list = self.api.get_model_list(experiment_id=experiment.id)
+        rf_model_dict = {
+            model_list[x]["corex_model_id"]: model_list[x]["_id"]
+            for x in range(len(model_list))
+        }
+        for algo_name in experiment.attributes.keys():
+            experiment.attributes[algo_name]["model_id"] = rf_model_dict[
+                experiment.attributes[algo_name]["model_id"]
+            ]
+
+        #### replace model_id in experiment.recommendations ###
+        for i in range(len(experiment.recommendations)):
+            experiment.recommendations[i]["model_id"] = rf_model_dict[
+                experiment.recommendations[i]["model_id"]
+            ]
+
         return experiment
 
     def train_ts(
@@ -325,6 +346,19 @@ class Client:
         )
 
         experiment = Experiment.parse_obj(self.wait_for_response("experiment", exp_id))
+
+        #### replace model_id in experiment.attributes ###
+        # res['experiment']['attributes'][{algo name}]['model_id'] is corex_model_id,
+        # so need to convert to web_model_id.
+        model_list = self.api.get_model_list(experiment_id=experiment.id)
+        rf_model_dict = {
+            model_list[x]["corex_model_id"]: model_list[x]["_id"]
+            for x in range(len(model_list))
+        }
+        for algo_name in experiment.attributes.keys():
+            experiment.attributes[algo_name]["model_id"] = rf_model_dict[
+                experiment.attributes[algo_name]["model_id"]
+            ]
         return experiment
 
     def predict_iid(
@@ -336,6 +370,7 @@ class Client:
         experiment_id: Optional[str] = None,
         model: Optional[Model] = None,
         threshold: Optional[float] = None,
+        download: int = 1,
     ) -> Prediction:
         """
         Predict model with test iid data.
@@ -374,7 +409,7 @@ class Client:
             attributes=self.wait_for_response("prediction", pred_id)
         )
         prediction.predict_df = self.api.get_pred_data(
-            prediction.attributes["_id"], data={"prediction_id": pred_id}
+            prediction.attributes["_id"], download
         )
 
         return prediction
@@ -387,6 +422,7 @@ class Client:
         model_id: Optional[str] = None,
         experiment_id: Optional[str] = None,
         model: Optional[Model] = None,
+        download: int = 1,
     ) -> Prediction:
         """
         Predict model with test timeseries data.
@@ -425,7 +461,7 @@ class Client:
             attributes=self.wait_for_response("prediction", pred_id)
         )
         prediction.predict_df = self.api.get_pred_data(
-            prediction.attributes["_id"], data={"prediction_id": pred_id}
+            prediction.attributes["_id"], download
         )
         return prediction
 
@@ -477,24 +513,88 @@ class Client:
         """
         return self.api.get_table(data_id=data_id)
 
-    def get_table_list(self) -> List[str]:
+    def get_table_list(self, page=1) -> List[str]:
         """
         Return list of table information.
 
+        Args:
+            page (int): page number.
+
         Returns:
         ----------
             (List[str])
                 List of uploaded table information.
         """
-        return self.api.get_table_list()
-    
+        return self.api.get_table_list(page)
+
     def get_model_list(self, experiment_id) -> List[str]:
         """
         Return list of model in specific experiment_id.
 
+        Args:
+            experiment_id
+
         Returns:
         ----------
             (List[str])
                 List of experiment information.
         """
         return self.api.get_model_list(experiment_id)
+
+    def get_pred_data(self, pred_id, download=1) -> pd.DataFrame:
+        """
+        Return result of prediction on specific prediction id.
+
+        Args:
+            pred_id: prediction id
+            download (int): download number.
+
+        Returns:
+        ----------
+            (pd.DataFrame)
+                DataFrame of prediction
+        """
+        return self.api.get_pred_data(pred_id, download)
+
+    def get_experiment_list(self, page=1) -> Dict:
+        """
+        Return Dictionary of all experiment on specific page
+
+        Args:
+            page (int): page number.
+
+        Returns:
+        ----------
+            (Dict)
+                Dictionary of all experiment including name and start time.
+        """
+        return self.api.get_experiment_list(page)
+
+    def get_prediction_list(self, model_id) -> List[Dict]:
+        """
+        Return List of dictionary of prediction
+
+        Args:
+            model_id
+
+        Returns:
+        ----------
+            (List[Dict])
+                List of dictionary of prediction
+        """
+        return self.api.get_prediction_list(model_id)
+
+    def get_model_threshold(self, experiment_id, model_id) -> float:
+        """
+        Return threshold by the cross-validation in specific experiment and model
+
+        Args:
+            experiment_id
+            model_id
+
+        Returns:
+        ----------
+            (float)
+                threshold
+        """
+        return self.api.get_model_threshold(experiment_id, model_id)
