@@ -450,6 +450,7 @@ class NonBlockingClient:
         model_id: Optional[str] = None,
         experiment_id: Optional[str] = None,
         model: Optional[Model] = None,
+        threshold: Optional[float] = None,
     ) -> str:
         """
         Predict model with test iid data.
@@ -491,6 +492,7 @@ class NonBlockingClient:
             "is_multi_model": False,
             "non_negative": non_negative,
             "keep_columns": keep_columns,
+            "threshold": threshold,
         }
 
         pred_id = self.api.post_predict(prediction_settings)
@@ -538,7 +540,7 @@ class NonBlockingClient:
         mod_id = model.model_id if model is not None else model_id
         exp_id = model.experiment_id if model is not None else experiment_id
         is_multi_model = False
-        for k in self.api.get_model_list(exp_id, {"projectId": self.project_id}):
+        for k in self.api.get_model_list(exp_id):
             if k["_id"] == mod_id:
                 is_multi_model = k["model_type"] in [
                     "ExodusModel",
