@@ -36,6 +36,7 @@ class DecanterApiClient(ApiClient):
             data=json.dumps(data),
             verify=False,
         )
+
         if not res.ok:
             raise RuntimeError(res.json()["message"])
         return res.json()["experiment"]["_id"]
@@ -103,26 +104,57 @@ class DecanterApiClient(ApiClient):
             ).json()
             return res["data"]
 
-    def get_pred_data(self, pred_id, data):  # pragma: no cover
+    def get_experiment_list(self, page):
+        experiment = {}
+        experiment_response = requests.get(
+            f"{self.url}experiment/getlist/{self.project_id}",
+            headers=self.headers,
+            params={"page": page},
+            verify=False,
+        )
+        for experiment_ in experiment_response.json()["experiments"]:
+            experiment_name = experiment_["name"]
+            create_time = pd.to_datetime(experiment_["started_at"][:19]) + pd.Timedelta(
+                8, unit="h"
+            )
+            experiment[experiment_["_id"]] = {
+                "ExperimentName": experiment_name,
+                "StartTime": create_time.strftime("%Y-%m-%d %H:%M"),
+            }
+        return experiment
+
+    def get_prediction_list(self, model_id):
+
+        res = requests.get(
+            f"{self.url}prediction/getlist/{model_id}",
+            verify=False,
+            params={"project_id": self.project_id},
+            headers=self.headers,
+        )
+
+        return res.json()["predictions"]
+
+    def get_pred_data(self, pred_id, download):  # pragma: no cover
 
         prediction_get_response = requests.get(
             f"{self.url}prediction/{pred_id}/download",
             headers=self.headers,
-            data=data,
+            params={"download": download},
             verify=False,
         )
 
         read_file = StringIO(prediction_get_response.text)
-        prediction_df = pd.read_csv(read_file)
+        prediction_df = pd.read_csv(read_file).reset_index()
 
         return prediction_df
 
-    def get_table_list(self):  # pragma: no cover
+    def get_table_list(self, page):  # pragma: no cover
 
         table_list_res = requests.get(
             f"{self.url}table/getlist/{self.project_id}",
             headers=self.headers,
             verify=False,
+            params={"page": page},
         )
         return table_list_res.json()["tables"]
 
@@ -148,6 +180,17 @@ class DecanterApiClient(ApiClient):
         )
         return res.json()["model_list"]
 
+    def get_model_threshold(self, experiment_id, model_id):  # pragma: no cover
+
+        res = requests.get(
+            f"{self.url}experiment/{experiment_id}/model/{model_id}",
+            headers=self.headers,
+            verify=False,
+        )
+        return res.json()["model"]["attributes"]["auc"]["cv_average"]["th_max_by"][
+            "evaluator"
+        ]
+
     def stop_uploading(self, id) -> bool:  # pragma: no cover
         res = requests.post(
             f"{self.url}table/stop",
